@@ -12,6 +12,15 @@ from datetime import datetime
 #         return super(DecimalEncoder, self)._iterencode(o, markers)
 
 
+class ModelEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if hasattr(obj, "attribute_values"):
+            return obj.attribute_values
+        elif isinstance(obj, datetime):
+            return obj.isoformat()
+        return json.JSONEncoder.default(self, obj)
+
+
 class APIFunction(LambdaFunction):
     def run(self, event, context):
         # Get the calling method and route appropriately.
@@ -52,7 +61,7 @@ class APIFunction(LambdaFunction):
         }
         return_obj["headers"] = headers
         if body or isinstance(body, list):
-            return_obj["body"] = json.dumps(body, default=datetime.isoformat)
+            return_obj["body"] = json.dumps(body, cls=ModelEncoder)
         return return_obj
 
     def get_methods(self):
