@@ -12,6 +12,8 @@ from .queue import Queue
 import bottle
 from functools import partial
 import importlib
+from pynamodb.models import Model
+from pynamodb.exceptions import TableError
 
 
 class Deployer(object):
@@ -119,6 +121,9 @@ class Deployer(object):
                 )
         return functions
 
+    def _get_pynamo_models(self):
+        return Model.__subclasses__()
+
     def _install_reqs(self):
         reqs = os.path.abspath(f"{self.dir}/requirements.txt")
         subprocess.run(["pip", "install", "-r", reqs], check=True)
@@ -127,11 +132,13 @@ class Deployer(object):
         # Running files to create subclasses.
         # TODO: Change these from hardcoded to dynamic.
         if os.path.isfile("queues.py"):
-            exec(open("queues.py").read())
+            importlib.import_module("queues")
         if os.path.isfile("function.py"):
-            exec(open("function.py").read())
+            importlib.import_module("function")
         if os.path.isfile("api.py"):
-            exec(open("api.py").read())
+            importlib.import_module("api")
+        if os.path.isfile("model.py"):
+            importlib.import_module("model")
 
     def _build_template(self, output_dir=None):
         # Checking custom output directory.
@@ -217,8 +224,30 @@ class Deployer(object):
         else:
             self._sam_build()
 
+    def _deploy_tables(self):
+        for model in self._get_pynamo_models():
+            if self.local:
+                model.Meta.host = "http://localhost:4566"
+
+            # TODO: Should probably decide if this is how we want it to work.
+            try:
+                if model.exists():
+                    model.delete_table()
+
+                model.create_table(wait=True)
+            except TableError as e:
+                if self.local:
+                    print(
+                        "Unable to connect to LocalStack to deploy DynamoDB tables. "
+                        "Have you started LocalStack on your machine ('localstack start')?"
+                    )
+                    exit(1)
+                else:
+                    raise e
+
     def deploy(self):
         self._build_template()
+        self._deploy_tables()
 
         # Creating S3 bucket for SAM.
         # TODO: Set this to create a random bucket if the name is taken or something.
@@ -252,12 +281,19 @@ class Deployer(object):
 
         print("Deployed successfully.")
 
+    def _start_infra(self):
+        # Saving for when I figure out how to actually run localstack
+        pass
+
     def start_api(self, method="local"):
         """Run the API layer locally."""
         if method == "sam":
             self._start_api_sam()
 
         elif method == "local":
+            self._source_files()
+            self._start_infra()
+            self._deploy_tables()
             self._start_api_local()
 
         else:
@@ -413,7 +449,6 @@ class Deployer(object):
         return res.get("body")
 
     def _start_api_local(self):
-        self._source_files()
         api_functions = self._get_api_functions()
 
         @bottle.route("/test")
@@ -444,3 +479,8 @@ class Deployer(object):
         self._build_template()
         self._build()
         subprocess.run(["sam", "local", "invoke", function], cwd=self.dir, check=True)
+
+
+if __name__ == "__main__":
+    deployer = Deployer("pilotproj", "../pilotproj")
+    deployer.start_api()
